@@ -6,23 +6,7 @@ use warnings;
 use Algorithm::Combinatorics qw(subsets variations);
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-use Exporter;
-our @ISA = qw(Exporter);
-our %EXPORT_TAGS = ('all'=>[qw(
-	validate_data
-	quantity_possible_rules
-	generate_rules
-	association_rules
-	stop
-	output
-	data_persistence
-	file
-	excel
-)]);
-our @EXPORT_OK = (@{$EXPORT_TAGS{'all'}});
-our @EXPORT = qw();
-
-our $VERSION = 0.11;
+our $VERSION = 0.12;
 
 my$self;
 
@@ -470,7 +454,7 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 
 	# or from a data file
 
-	# $apriori->input_data_file("datafile.txt",",");
+	$apriori->input_data_file("datafile.txt",",");
 	# Insert items per line(transaction), accepts the arguments of path to data file and item separator
 
 	# file contents
